@@ -9,8 +9,9 @@ import textwrap
 
 from typing import List, Dict, Optional, Tuple, Any
 
-from gql import Client, gql  # type: ignore
-from gql.transport.requests import RequestsHTTPTransport  # type: ignore
+from gql import Client, gql
+from gql.transport.aiohttp import AIOHTTPTransport
+from gql.client import DocumentNode
 
 from transform_tools.validate import (
     validate_configs as tt_validate_configs,
@@ -59,25 +60,21 @@ class BaseInterface:
     Assumes that authorization and GraphQL query pattern are the same across Backend, and MQL APIs
     """
 
-    def __init__(self, auth_header: Dict[str, str], rest_api_url: str, verify: bool = True) -> None:  # noqa: D
+    def __init__(self, auth_header: Dict[str, str], rest_api_url: str) -> None:  # noqa: D
         self.rest_api_url = rest_api_url
         self.auth_header = auth_header
-        self.verify = verify
 
         self.gql_client = Client(
-            transport=RequestsHTTPTransport(
-                url=self.graphql_api_url, verify=self.verify, retries=2, headers=self.auth_header
-            ),
+            transport=AIOHTTPTransport(url=self.graphql_api_url, headers=self.auth_header),
             fetch_schema_from_transport=False,
+            execute_timeout=90,  # 1.5 minute
         )
 
-    def execute(  # type: ignore [misc]
-        self, query: gql, verbose: bool = False, variable_values: Dict[str, Any] = None
-    ) -> Dict[str, Any]:
+    def execute(self, query: DocumentNode, verbose: bool = False, variable_values: Dict[str, Any] = None) -> Dict[str, Any]:  # type: ignore[misc]
         """Error handling for GQL Clients"""
         start_time = time.time()
         try:
-            response = self.gql_client.execute(query, variable_values)
+            response = self.gql_client.execute(query, variable_values=variable_values)
         except requests.exceptions.ConnectionError:
             raise Exception(
                 textwrap.dedent(
@@ -91,7 +88,12 @@ class BaseInterface:
                 )
             )
         except Exception as e:
-            exception_response = str(e.args[0])
+            # It's possible for e.args to be an empty tuple, so we have to
+            # guard against that
+            exception_response = ""
+            if len(e.args) > 0:
+                exception_response = str(e.args[0])
+
             if "Authentication hook unauthorized" in exception_response:
                 raise Exception(
                     textwrap.dedent(
@@ -110,7 +112,7 @@ class BaseInterface:
                     )
                 )
             else:
-                raise
+                raise e
         logger.debug(f"Query for {' '.join(response.keys())} took {(time.time() - start_time):.2f}s")
         return response
 
@@ -120,10 +122,8 @@ class BaseInterface:
 
 
 class BackendInterface(BaseInterface):  # noqa: D
-    def __init__(  # noqa: D
-        self, auth_header: Dict[str, str], rest_api_url: str = TRANSFORM_PROD_API, verify: bool = True
-    ) -> None:
-        super(BackendInterface, self).__init__(auth_header, rest_api_url, verify)
+    def __init__(self, auth_header: Dict[str, str], rest_api_url: str = TRANSFORM_PROD_API) -> None:  # noqa: D
+        super(BackendInterface, self).__init__(auth_header, rest_api_url)
 
     def validate_configs(self, config_dir: str) -> ModelKey:
         """Finds and validates yaml configs in the provided directory"""
