@@ -23,7 +23,7 @@ from .models import (
     TimeGranularity,
     UserState,
 )
-from .interfaces import MQLInterface
+from .interfaces import DWValidationType, MQLInterface
 
 
 class MQLClient:
@@ -293,8 +293,8 @@ class MQLClient:
         dimensions = self.context.mql_client.get_dimensions(model_key)
         return {dim.name: dim for dim in dimensions}
 
-    def validate_model_against_data_warehouse(self, model_key_id: Optional[int] = None) -> List[str]:
-        """Retrieves a list of any and all data warehosue validation issues with the model."""
+    def get_data_warehouse_issues(self, type: DWValidationType, model_key_id: Optional[int] = None) -> List[str]:
+        """Retrieves a list of warehosue validation issues with for the type on the model."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
-        issues = self.context.mql_client.get_all_data_warehouse_validation_issues(model_key)
+        issues = self.context.mql_client.get_data_warehouse_validation_issues(type, model_key)
         return issues
